@@ -158,7 +158,8 @@ send_dbus_string_signal (GdmSessionDirect *session,
         dbus_message_iter_append_basic (&iter, DBUS_TYPE_STRING, &text);
 
         if (! send_dbus_message (session->priv->worker_connection, message)) {
-                g_debug ("GdmSessionDirect: Could not send %s signal", name);
+                g_debug ("GdmSessionDirect: Could not send %s signal",
+                         name ? name : "(null)");
         }
 
         dbus_message_unref (message);
@@ -270,7 +271,7 @@ gdm_session_direct_handle_setup_failed (GdmSessionDirect *session,
 
         g_debug ("GdmSessionDirect: Emitting 'setup-failed' signal");
 
-        _gdm_session_setup_failed (GDM_SESSION (session), NULL);
+        _gdm_session_setup_failed (GDM_SESSION (session), text);
 
         return DBUS_HANDLER_RESULT_HANDLED;
 }
@@ -316,7 +317,7 @@ gdm_session_direct_handle_reset_failed (GdmSessionDirect *session,
 
         g_debug ("GdmSessionDirect: Emitting 'reset-failed' signal");
 
-        _gdm_session_reset_failed (GDM_SESSION (session), NULL);
+        _gdm_session_reset_failed (GDM_SESSION (session), text);
 
         return DBUS_HANDLER_RESULT_HANDLED;
 }
@@ -334,6 +335,7 @@ gdm_session_direct_handle_authenticated (GdmSessionDirect *session,
         dbus_connection_send (connection, reply, NULL);
         dbus_message_unref (reply);
 
+        session->priv->is_authenticated = TRUE;
         _gdm_session_authenticated (GDM_SESSION (session));
 
         return DBUS_HANDLER_RESULT_HANDLED;
@@ -361,7 +363,8 @@ gdm_session_direct_handle_authentication_failed (GdmSessionDirect *session,
 
         g_debug ("GdmSessionDirect: Emitting 'authentication-failed' signal");
 
-        _gdm_session_authentication_failed (GDM_SESSION (session), NULL);
+        session->priv->is_authenticated = FALSE;
+        _gdm_session_authentication_failed (GDM_SESSION (session), text);
 
         return DBUS_HANDLER_RESULT_HANDLED;
 }
@@ -406,7 +409,7 @@ gdm_session_direct_handle_authorization_failed (GdmSessionDirect *session,
 
         g_debug ("GdmSessionDirect: Emitting 'authorization-failed' signal");
 
-        _gdm_session_authorization_failed (GDM_SESSION (session), NULL);
+        _gdm_session_authorization_failed (GDM_SESSION (session), text);
 
         return DBUS_HANDLER_RESULT_HANDLED;
 }
@@ -451,7 +454,7 @@ gdm_session_direct_handle_accreditation_failed (GdmSessionDirect *session,
 
         g_debug ("GdmSessionDirect: Emitting 'accreditation-failed' signal");
 
-        _gdm_session_accreditation_failed (GDM_SESSION (session), NULL);
+        _gdm_session_accreditation_failed (GDM_SESSION (session), text);
 
         return DBUS_HANDLER_RESULT_HANDLED;
 }
@@ -1158,18 +1161,6 @@ session_worker_message (DBusConnection *connection,
                 return gdm_session_direct_handle_accredited (session, connection, message);
         } else if (dbus_message_is_method_call (message, GDM_SESSION_DBUS_INTERFACE, "AccreditationFailed")) {
                 return gdm_session_direct_handle_accreditation_failed (session, connection, message);
-        } else if (dbus_message_is_method_call (message, GDM_SESSION_DBUS_INTERFACE, "Authenticated")) {
-                return gdm_session_direct_handle_authenticated (session, connection, message);
-        } else if (dbus_message_is_method_call (message, GDM_SESSION_DBUS_INTERFACE, "AuthenticationFailed")) {
-                return gdm_session_direct_handle_authentication_failed (session, connection, message);
-        } else if (dbus_message_is_method_call (message, GDM_SESSION_DBUS_INTERFACE, "Authorized")) {
-                return gdm_session_direct_handle_authorized (session, connection, message);
-        } else if (dbus_message_is_method_call (message, GDM_SESSION_DBUS_INTERFACE, "AuthorizationFailed")) {
-                return gdm_session_direct_handle_authorization_failed (session, connection, message);
-        } else if (dbus_message_is_method_call (message, GDM_SESSION_DBUS_INTERFACE, "Accredited")) {
-                return gdm_session_direct_handle_accredited (session, connection, message);
-        } else if (dbus_message_is_method_call (message, GDM_SESSION_DBUS_INTERFACE, "AccreditationFailed")) {
-                return gdm_session_direct_handle_accreditation_failed (session, connection, message);
         } else if (dbus_message_is_method_call (message, GDM_SESSION_DBUS_INTERFACE, "UsernameChanged")) {
                 return gdm_session_direct_handle_username_changed (session, connection, message);
         } else if (dbus_message_is_method_call (message, GDM_SESSION_DBUS_INTERFACE, "SessionStarted")) {
@@ -1569,11 +1560,7 @@ worker_exited (GdmSessionWorkerJob *job,
         g_debug ("GdmSessionDirect: Worker job exited: %d", code);
 
         if (!session->priv->is_authenticated) {
-                char *msg;
-
-                msg = g_strdup_printf (_("worker exited with status %d"), code);
-                _gdm_session_authentication_failed (GDM_SESSION (session), msg);
-                g_free (msg);
+                _gdm_session_authentication_failed (GDM_SESSION (session), NULL);
         } else if (session->priv->is_running) {
                 _gdm_session_session_exited (GDM_SESSION (session), code);
         }
@@ -1587,11 +1574,7 @@ worker_died (GdmSessionWorkerJob *job,
         g_debug ("GdmSessionDirect: Worker job died: %d", signum);
 
         if (!session->priv->is_authenticated) {
-                char *msg;
-
-                msg = g_strdup_printf (_("worker exited with status %d"), signum);
-                _gdm_session_authentication_failed (GDM_SESSION (session), msg);
-                g_free (msg);
+                _gdm_session_authentication_failed (GDM_SESSION (session), NULL);
         } else if (session->priv->is_running) {
                 _gdm_session_session_died (GDM_SESSION (session), signum);
         }
@@ -1971,9 +1954,12 @@ setup_session_environment (GdmSessionDirect *session)
                                                      "GDM_LANG",
                                                      get_language_name (session));
 
-        gdm_session_direct_set_environment_variable (session,
-                                                     "GDM_KEYBOARD_LAYOUT",
-                                                     get_layout_name (session));
+        if (strcmp (get_layout_name (session),
+                    get_default_layout_name (session)) == 0) {
+                gdm_session_direct_set_environment_variable (session,
+                                                             "GDM_KEYBOARD_LAYOUT",
+                                                             get_layout_name (session));
+        }
 
         gdm_session_direct_set_environment_variable (session,
                                                      "DISPLAY",
